@@ -20,6 +20,13 @@ describe GrapePathHelpers::NamedRouteMatcher do
     fake_class.new
   end
 
+  it 'is available inside Grape endpoints' do
+    endpoint = Spec::Support::API.endpoints.first
+
+    expect(endpoint.api_v1_cats_path(id: 5))
+      .to eq('/api/v1/cats/5.json')
+  end
+
   describe '#method_missing' do
     it 'returns super method_missing if the route does not exist' do
       expect(helper_class.test_method(id: 1))
